#
# spec file for package python-json_tricks
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-json_tricks
Version:        3.17.3
Release:        2.2
Summary:        Extra features for Python's JSON
License:        BSD-3-Clause
URL:            https://github.com/mverleg/pyjson_tricks
Source:         https://github.com/mverleg/pyjson_tricks/archive/v%{version}.tar.gz#/pyjson_tricks-%{version}.tar.gz
# PATCH-FIX-UPSTREAM gh#mverleg/pyjson_tricks#102
Patch0:         support-pytest-8.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Recommends:     python-numpy
Recommends:     python-pandas
Recommends:     python-pytz
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz}
# /SECTION
%python_subpackages

%description
The json_tricks package brings several pieces of functionality to
python handling of json files:

1. Store and load numpy arrays in human-readable format.
2. Store and load class instances both generic and customized.
3. Store and load date/times as a dictionary (including timezone).
4. Preserve map order {} using OrderedDict.
5. Allow for comments in json files by starting lines with #.
6. Sets, complex numbers, Decimal, Fraction, enums, compression, duplicate keys, ...

As well as compression and disallowing duplicate keys.

%prep
%autosetup -p1 -n pyjson_tricks-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE.txt
%{python_sitelib}/json_tricks
%{python_sitelib}/json_tricks-%{version}.dist-info

%changelog
* Mon Aug 19 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-pytest-8.patch:
  * Do not use pytest.warns(None).
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 3.17.3:
  * drop python 2 support
  * datetime fixes
* Sat Jun 17 2023 Christian Boltz <suse-beta@cboltz.de>
- Update to 3.17.1
  * no upstream changelog
* Tue May 16 2023 Christian Boltz <suse-beta@cboltz.de>
- Update to 3.16.1
  * no upstream changelog
* Thu Jul 14 2022 Ben Greiner <code@bnavigator.de>
- Remove ancient pathlib requirement for python3. It is part of the
  stdlib since Python 3.4
* Mon Apr 19 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.15.5:
  * Attempt py3.9 support
  * Allow none as encoder class for dump(s), for compatibility
  * Fix Numpy Array with shape (0,N) not decoded correctly.
- Do not build for Python 3.6, due to no NumPy.
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Thu Apr 16 2020 pgajdos@suse.com
- version update to 3.15.2
  * Deprecation warning ignore_comments
  * Fix the code and tests for python2
* Mon Apr  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.15.0:
  * no upstream changelog
* Thu Sep  5 2019 Todd R <toddrme2178@gmail.com>
- Update to 3.13.2:
  * Move the version number to a Python file
  * Tests failed because type of error had changed
  * Add json_tricks.__version__
* Tue Mar 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.13.1:
  * add support for pathlib
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Aug  7 2018 toddrme2178@gmail.com
- Update to 3.12.2
  * Fix for unterminated string exception in object containing
    empty string
* Sat May 26 2018 toddrme2178@gmail.com
- Initial version
